@@ -13,12 +13,13 @@ def wget(url, verify=True):
 def extract_ova_from_zip(zipfile):
 	import zipfile
 
+	ovafile = zipfile.replace('.zip','.ova')
 	cur_folder = os.path.abspath(os.curdir)
 	with zipfile.ZipFile(local_zip_file,"r") as zip_ref:
 		zip_ref.extractall(cur_folder)
 	os.remove(zipfile)
 
-	return os.path.exists(zipfile.replace('.zip','.ova'))
+	return ovafile if os.path.exists(ovafile) else None
 
 def open_port():
 	"""
